from setuptools import setup

setup(
    name="s3utilz",
    description="A s3 connection and read/write module for Python",
    author = "Zebracat AI",
    version="0.1.0",
    install_requires=["boto3"],
)